@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -
 from flask_sqlalchemy import SQLAlchemy
-from gt_flask import GtFlask
-from constant import VERSION
+from .gt_flask import GtFlask
+from .constant import VERSION
 import logging.config
 import os
 import importlib
@@ -14,7 +14,7 @@ def create_log_path(log_path):
         os.makedirs(log_path)
 
 def create_app(config):
-    create_log_path(config.LOG_DIR)
+    create_log_path(config.logger_dict['path'])
     logging.config.dictConfig(config.logger_dict)
     global app
     app = GtFlask(__name__)
